@@ -72,7 +72,7 @@ apply_settings (GpsDataLoggerWidget * self)
     if (self->settings->method_cwp)
         my_method = my_method | LOCATION_METHOD_CWP;
     if (self->settings->interval == 0)
-	    my_interval = LOCATION_INTERVAL_1S;
+        my_interval = LOCATION_INTERVAL_1S;
     else if (self->settings->interval == 1)
         my_interval = LOCATION_INTERVAL_2S;
     else if (self->settings->interval == 2)
@@ -207,6 +207,7 @@ settings_dialog_new (GpsDataLoggerWidget * self)
     gchar *text;
     int i;
 
+    /* dialog title */
     dialog = gtk_dialog_new_with_buttons (_("GPS Data Logger Widget Settings"),
 					  NULL, /* parent */
 					  GTK_DIALOG_DESTROY_WITH_PARENT |
@@ -510,7 +511,7 @@ debuglog_close(GpsDataLoggerWidget * self)
 static void
 debuglog_start(GpsDataLoggerWidget * self)
 {
-    /* gchar *path; */
+    gchar *path;
     time_t current;
     struct tm *tp;
 
@@ -521,9 +522,7 @@ debuglog_start(GpsDataLoggerWidget * self)
     /* Name the log file using the current time */
     current = time(NULL);
     tp = localtime(&current);
-    if (self->path != NULL)
-	g_free(self->path);
-    self->path = g_strdup_printf("%s/%d%02d%02d_%02d%02d%02d.log", 
+    path = g_strdup_printf("%s/%d%02d%02d_%02d%02d%02d.log", 
 		           self->settings->log_folder,
 		    	   tp->tm_year + 1900,
 		   	   tp->tm_mon + 1,
@@ -531,8 +530,8 @@ debuglog_start(GpsDataLoggerWidget * self)
 		   	   tp->tm_hour,
 		   	   tp->tm_min,
 		   	   tp->tm_sec );
-    self->logfile = fopen(self->path, "w");
-    /* g_free(path); */
+    self->logfile = fopen(path, "w");
+    g_free(path);
     
 }
 #endif
@@ -554,7 +553,7 @@ logfile_close(GpsDataLoggerWidget * self)
 static void
 logfile_start(GpsDataLoggerWidget * self)
 {
-    gchar *path;
+    /* gchar *path; */
     time_t current;
     struct tm *tp;
     char string_buf[5];
@@ -569,13 +568,16 @@ logfile_start(GpsDataLoggerWidget * self)
     } else {
         self->has_comma_as_decimal_point = FALSE;
     }
-    /* If the logfile is already open (should not) then close it */
+    /* If the logfile is already open (should not happen) then close it */
     if (self->file)
         logfile_close(self);
     /* Name the log file using the current time */
     current = time(NULL);
     tp = localtime(&current);
-    path = g_strdup_printf("%s/%d%02d%02d_%02d%02d%02d.gpx", 
+    if (self->path) {
+	g_free(self->path);
+    }
+    self->path = g_strdup_printf("%s/%d%02d%02d_%02d%02d%02d.gpx", 
 		           self->settings->log_folder,
 		    	   tp->tm_year + 1900,
 		   	   tp->tm_mon + 1,
@@ -583,12 +585,22 @@ logfile_start(GpsDataLoggerWidget * self)
 		   	   tp->tm_hour,
 		   	   tp->tm_min,
 		   	   tp->tm_sec );
-    self->file = fopen(path, "w");
+    if (! self->path) {
+        /* out of memory?? */
+        self->app_state = APP_STATE_IDLE;
+        location_gpsd_control_stop(self->control);
+        update_status_and_buttons(self);
+        hildon_banner_show_informationf(NULL,
+                        NULL,
+                        _("Could not open the GPX file for writing!"));
+	return;
+    }
+    self->file = fopen(self->path, "w");
     if (! (self->file)) {
         hildon_banner_show_informationf(NULL,
                         NULL,
                         _("Could not open \"%s\" for writing!"),
-			path);
+			self->path);
 #ifndef __arm__
 	g_print(_("Could not open logfile for writing, going to IDLE\n"));
 #endif
@@ -605,7 +617,7 @@ logfile_start(GpsDataLoggerWidget * self)
         g_fprintf(self->file, "<trk>\n");
         g_fprintf(self->file, "<trkseg>\n");
     }
-    g_free(path);
+    /* g_free(path); */
 }
 
 static void
@@ -631,17 +643,21 @@ update_status_and_buttons (GpsDataLoggerWidget * self)
 		break;
 	case APP_STATE_RECORDING:
 		gtk_image_set_from_pixbuf (GTK_IMAGE(self->gps_status), 
-				           self->gps_on_icon);
+				           self->has_fix ? self->gps_on_icon : self->gps_refresh_icon);
 		gtk_image_clear(GTK_IMAGE(self->auto_pause_status));
 		self->pause_button_visible = TRUE;
 		self->rec_button_enabled = TRUE;
 		self->stop_button_enabled = TRUE;
 		break;
 	case APP_STATE_PAUSED:
+		gtk_image_set_from_pixbuf (GTK_IMAGE(self->gps_status), 
+				           self->has_fix ? self->gps_on_icon : self->gps_refresh_icon);
 		gtk_image_clear(GTK_IMAGE(self->auto_pause_status));
 		self->pause_button_visible = FALSE;
 		break;
 	case APP_STATE_AUTO_PAUSED:
+		gtk_image_set_from_pixbuf (GTK_IMAGE(self->gps_status), 
+				           self->has_fix ? self->gps_on_icon : self->gps_refresh_icon);
 		gtk_image_set_from_pixbuf (GTK_IMAGE(self->auto_pause_status),
 				           self->pause_icon);
 		break;
@@ -707,7 +723,8 @@ handle_button_press (GtkWidget *button,
 	    g_usleep(500);
 	    location_gps_device_reset_last_known(self->device);
 	}
-	else if (self->app_state == APP_STATE_RECORDING) {
+	else if ((self->app_state == APP_STATE_RECORDING) ||
+		 (self->app_state == APP_STATE_AUTO_PAUSED)) {
             self->app_state = APP_STATE_PAUSED;
 #ifndef __arm__
 	    g_print(" new state: paused\n");
@@ -999,10 +1016,41 @@ on_changed(LocationGPSDevice *device, gpointer data)
 	char string_buf[256];
 	int i;
 	
+#ifdef DEBUG
+        if (self->logfile) {
+            g_fprintf(self->logfile, "%s -- enter, state: %d\n", __func__, self->app_state);
+	    fflush(self->logfile);
+        }
+#endif
         if (!device)
                 return;
-
-        if (device->fix) {
+	/* if there is no fix, or we are recording, but the fix is so
+	 * bad that it is a 2D fix only, with no time set then show
+	 * the refresh icon and autopause if that is allowed. */
+	if ((device->status == LOCATION_GPS_DEVICE_STATUS_NO_FIX) ||
+	    ((device->fix) && (self->app_state == APP_STATE_RECORDING) &&
+	     (! device->fix->fields & LOCATION_GPS_DEVICE_TIME_SET) &&
+	     (device->fix->mode == LOCATION_GPS_DEVICE_MODE_2D))) {
+		/* fix is lost */
+		self->has_fix = FALSE;
+		/* if auto_pause is enabled, let's engage that too */
+		if ((self->app_state == APP_STATE_RECORDING) &&
+		    (self->settings->auto_pause))
+			self->app_state = APP_STATE_AUTO_PAUSED;
+		update_status_and_buttons(self);
+	} else if (device->fix) {
+#ifdef DEBUG
+                if (self->logfile) {
+                    g_fprintf(self->logfile, "  fix fiels: %d, fix mode: %d, accuracy (m): %.0f\n", device->fix->fields, device->fix->mode, device->fix->eph / 100);
+	            fflush(self->logfile);
+                }
+#endif
+		if ((! self->has_fix) && 
+		    (device->fix->fields & LOCATION_GPS_DEVICE_LATLONG_SET)) {
+		    /* fix found again */
+		    self->has_fix = TRUE;
+		    update_status_and_buttons(self);
+		}
 		if (((self->app_state == APP_STATE_STARTING) ||
 		     (self->app_state == APP_STATE_RECORDING) ||
 		     (self->app_state == APP_STATE_AUTO_PAUSED)) &&
@@ -1083,8 +1131,24 @@ on_changed(LocationGPSDevice *device, gpointer data)
 			g_fprintf(self->file, "  <sat>%d</sat>\n",
 					device->satellites_in_use);
 			/* eph is in cm */
-			g_fprintf(self->file,  "  <hdop>%.1f</hdop>\n", device->fix->eph / 100.0);
-			g_fprintf(self->file,  "  <vdop>%.1f</vdop>\n", device->fix->epv);
+			g_snprintf(string_buf, 256, "  <hdop>%.2f</hdop>\n",
+						device->fix->eph / 100.0);
+			if (self->has_comma_as_decimal_point) {
+			    for (i=0; i<sizeof(string_buf); i++) {
+			        if (string_buf[i] == ',')
+			            string_buf[i] = '.';
+			    }
+			}
+			g_fprintf(self->file, string_buf);
+			g_snprintf(string_buf, 256, "  <vdop>%.2f</vdop>\n",
+						device->fix->epv);
+			if (self->has_comma_as_decimal_point) {
+			    for (i=0; i<sizeof(string_buf); i++) {
+			        if (string_buf[i] == ',')
+			            string_buf[i] = '.';
+			    }
+			}
+			g_fprintf(self->file, string_buf);
 			g_fprintf(self->file, "</trkpt>\n");
 			self->points_recorded_in_current_segment += 1;
 		} /* STARING & RECORDING & has coordinates */
@@ -1130,7 +1194,7 @@ on_changed(LocationGPSDevice *device, gpointer data)
                                 device->fix->eps,
                                 device->fix->epc);
 #endif
-        } /* device->fix */
+	} /* device->fix */
 
 #ifndef __arm__
         g_printf("%s:%s: Satellites in view: %d\n",
@@ -1337,28 +1401,26 @@ void hw_event_handler(osso_hw_state_t *state, gpointer data)
         }
 #endif
     }
-/*    if (state->memory_low_ind)
-    {
-        hildon_banner_show_information(NULL, NULL, 
-                                       "Memory low event!");
 #ifdef DEBUG
+    if (state->memory_low_ind)
+    {
+/*        hildon_banner_show_information(NULL, NULL, 
+                                       "Memory low event!"); */
         if (self->logfile) {
             g_fprintf(self->logfile, "  Memory low event!\n");
             fflush(self->logfile);
         }
-#endif
     }
     if (state->system_inactivity_ind)
     {
-        hildon_banner_show_information(NULL, NULL, 
-                                       "Minimize application inactivity event!");
-#ifdef DEBUG
+/*        hildon_banner_show_information(NULL, NULL, 
+                                       "Minimize application inactivity event!"); */
         if (self->logfile) {
             g_fprintf(self->logfile, "  Minimize application inactivity event!\n");
             fflush(self->logfile);
         }
+    }
 #endif
-    } */
     /* shall we stop recording and flush the log? */
     if ((self->app_state != APP_STATE_IDLE) && should_stop_recording) {
         /* let's prettend that the user pressed stop */
