@@ -9,6 +9,9 @@
 #define GCONF_METHOD_ACWP_KEY  GCONF_PATH"/method_acwp"
 #define GCONF_METHOD_CWP_KEY   GCONF_PATH"/method_cwp"
 #define GCONF_INTERVAL_KEY     GCONF_PATH"/interval"
+#define GCONF_AUTO_PAUSE_KEY     		GCONF_PATH"/auto_pause"
+#define GCONF_PAUSE_SPEED_THRESHOLD_KEY		GCONF_PATH"/pause_speed_threshold"
+#define GCONF_PAUSE_TIME_THRESHOLD_KEY		GCONF_PATH"/pause_time_threshold"
 #define GCONF_LOG_FOLDER_KEY   GCONF_PATH"/log_folder"
 
 GpsDataLoggerSettings *
@@ -47,6 +50,24 @@ settings_load (void)
         (settings->interval > 7))
         settings->interval = 1; /* 2 seconds */
 
+    settings->auto_pause = gconf_client_get_bool(client,
+		    		GCONF_AUTO_PAUSE_KEY,
+				NULL);
+    settings->pause_speed_threshold = gconf_client_get_int(client,
+		    		GCONF_PAUSE_SPEED_THRESHOLD_KEY,
+				NULL);
+    /* sanitize speed threshold */
+    if ((settings->auto_pause) &&
+	(settings->pause_speed_threshold < 0))
+	settings->pause_speed_threshold = 1;    
+    settings->pause_time_threshold = gconf_client_get_int(client,
+		    		GCONF_PAUSE_TIME_THRESHOLD_KEY,
+				NULL);
+    /* sanitize time threshold */
+    if ((settings->auto_pause) &&
+	(settings->pause_time_threshold < 1))
+	settings->pause_time_threshold = 1;    
+    
     settings->log_folder = gconf_client_get_string(client,
 		    		GCONF_LOG_FOLDER_KEY,
 				NULL);
@@ -99,6 +120,27 @@ gboolean settings_save (GpsDataLoggerSettings * settings)
         g_object_unref (G_OBJECT (client));
         return FALSE;
     }
+    if (! gconf_client_set_bool(client,
+			    GCONF_AUTO_PAUSE_KEY,
+			    settings->auto_pause,
+			    NULL)) {
+        g_object_unref (G_OBJECT (client));
+        return FALSE;
+    }
+    if (! gconf_client_set_int(client,
+			    GCONF_PAUSE_SPEED_THRESHOLD_KEY,
+			    settings->pause_speed_threshold,
+			    NULL)) {
+        g_object_unref (G_OBJECT (client));
+        return FALSE;
+    }
+    if (! gconf_client_set_int(client,
+			    GCONF_PAUSE_TIME_THRESHOLD_KEY,
+			    settings->pause_time_threshold,
+			    NULL)) {
+        g_object_unref (G_OBJECT (client));
+        return FALSE;
+    }
     if (! gconf_client_set_string(client,
 			    GCONF_LOG_FOLDER_KEY,
 			    settings->log_folder,
