@@ -13,6 +13,9 @@ struct _GpsDataLoggerSettings {
     gboolean	method_acwp;
     gboolean	method_cwp;
     gint	interval;
+    gboolean	auto_pause;
+    gint	pause_speed_threshold;
+    gint	pause_time_threshold;
     char	*log_folder;
 };
 
